% FIG10_4,  `Coordinates and parameters of a conic surface'.
% Original file name CONCOORD.
 % Written by Adrian Biran for the book `What every engineer should know
 % about MATLAB and Simulink'

% define frame
plot([ 5 5 ], [ -0.5 5.5 ], 'k-.', [ 5 5 ], [ -8 -1.5 ], 'k-.', [ 15 15 ], [ 0 5 ], 'r-')

R    = 2.5;                                                     % base radius
H    = 5;                                                        % cone height
t    = 0: 5: 360;                                           % parameter for complete circles

axis equal, axis off

hold on
plot([ 1.5 8 ], [ -4.5 -4.5 ], 'k-.', [ 12.5 17.5 ], [ -4.5 -4.5 ], 'r-')
% left cone
ht = text(1, 7, 'a)');
set(ht, 'FontSize', 14)
xc1 =  5 + R*cosd(t);
yc1 = -4.5 + R*sind(t);
hp   = plot(xc1, yc1, 'k-');
set(hp, 'LineWidth', 1.5)
hp = plot([ 2.5 5 7.5 2.5 ], [ 0 5 0 0 ], 'k-');
set(hp, 'LineWidth', 1.5)
arrow([ 8; 0 ], [ 9; 0 ], 0.13)
ht = text(9.1, 0.3, 'x');
set(ht, 'FontSize', 14)
arrow([ 5; 5.9 ], [ 5; 7 ], 0.13)
ht = text(4.9, 7.5, 'z');
set(ht, 'FontSize', 14)
plot([ 5 (5 + R*cosd(45)) ], [ -4.5 (-4.5 + R*sind(45)) ], 'k-')
t1  = 0: 45;
r1  = 1.5;
x1  = 5 + r1*cosd(t1);
y1  = -4.5 + r1*sind(t1);
plot(x1, y1, 'k-')
arrow([ 6.5; -4.1 ], [ 6.5 -4.5 ], 0.08)
arrow([ 6.25; -3.75 ], [ 6.15 -3.5 ], 0.08)
text(6.6, -3.8, '2 \pi u')
% mark semi-angle at cone vertex
t1  = 270: 300;
r1  = 2.3;
x1  = 5 + r1*cosd(t1);
y1  = 5 + r1*sind(t1);
plot(x1, y1, 'k-')
arrow([ 4.4; 2.7 ], [ 4.9 2.7 ], 0.08)
arrow([ 6.4; 3.3 ], [ 5.9 2.9 ], 0.08)
text(5.1, 3.3, ' \alpha')
% mark cone height
plot([ 0.9 2.5 ], [ 0 0 ], 'k-')
plot([ 0.9 5 ], [ 5 5 ], 'k-')
arrow([ 1; 2.5 ], [ 1; 0 ], 0.13)
arrow([ 1; 2.5 ], [ 1; 5 ], 0.13)
ht = text(0.6, 2,5, 'H', 'Rotation', 90);
set(ht, 'FontSize', 14)
arrow([ 5; 2 ], [ 6.5; 2 ], 0.13)
ht = text(5.4, 2.4, 'r');
set(ht, 'FontSize', 14)

% right cone
ht = text(11, 7, 'b)');
set(ht, 'FontSize', 14)
xc2 =  15 + R*cosd(t);
yc2 = -4.5 + R*sind(t);
hp   = plot(xc2, yc2, 'k-');
set(hp, 'LineWidth', 1.5)
hp = plot([ 12.5 15 17.5 12.5 ], [ 0 5 0 0 ], 'k-');
set(hp, 'LineWidth', 1.5)
set(ht, 'FontSize', 14)
arrow([ 5; -1.6 ], [ 5; -0.5 ], 0.13)
ht = text(5.1, -0.5, 'y');
set(ht, 'FontSize', 14)
% coordinate network
% u parameter
text(18, -4.2, 'u = 0, u = 1')
plot([ 15 15 ], [ -7 -2 ], 'r-')
t2 = 45;                                            % degrees
plot([ 15  (15 + R*cosd(t2) )], [ -4.5 (-4.5 + R*sind(t2)) ], 'r-')
text( 16.8, -2.5, 'u = 0.125')
text(15.2, -1.6, 'u = 0.25')
t2 = 135;                                            % degrees
plot([ 15  (15 + R*cosd(t2) )], [ -4.5 (-4.5 + R*sind(t2)) ], 'r-')
text( 10.6, -2.5, 'u = 0.375')
text(10.4, -4.2, 'u = 0.5')
t2 = 225;                                            % degrees
plot([ 15  (15 + R*cosd(t2) )], [ -4.5 (-4.5 + R*sind(t2)) ], 'r-')
text( 10.6, -6.5, 'u = 0.625')
plot([ (15 + R*cosd(t2) ) 15 ], [ 0 5 ], 'r-')
text(15.2, -7.4, 'u = 0.75')
t2 = 315;                                            % degrees
plot([ 15  (15 + R*cosd(t2) )], [ -4.5 (-4.5 + R*sind(t2)) ], 'r-')
text( 16.8, -6.5, 'u = 0.875')
plot([ (15 + R*cosd(t2) ) 15 ], [ 0 5 ], 'r-')
% v parameter
text(15, 5.3, 'v = 0')
for k = 1:2:9
    h   = k*H/10;
    b   = R*(1 - h/H);
    b1 = 15 - b;
    b2 = 15 + b;
    plot([ b1 b2 ], [ h h ], 'b-')
    vt = (10 - k)/10;
    text((b2 + 0.2), h, [ 'v = ' num2str(vt) ])
    xp = 15 + b*cosd(t);
    yp =  -4.5 + b*sind(t);
    plot(xp, yp, 'b-')
    
end    

hold off