function    g = FourLink1(l1, l2, l3, l4)

%FOURLINK1   Simulation of four-link mechanism - Figure that explains the
%           mathematics involved.
%           The input consists of the lenghts of the four lenghts l1, l2,
%           l3, l4, where l4 connects the two fixed points P0 and P3. 
%           Internal variables are the angles t1, t2, t3.
%           As an example call the function with
%           FourLink(1, 3, 3, 4)

P0 = [  0; 0 ];
P3 = [ l4; 0 ];
% define frame
Hp = plot([ 0 l4 ], [ 0 0 ], 'k-');
set(Hp, 'LineWidth', 1.5)
axis([ -1.05*l1 1.2*l4 -0.1*l3 1.01*l3 ])
axis equal
axis off
hold on
point(P0, 0.07);
point(P3, 0.07);
t0 = 0: pi/30: 2*pi;  % parameter of articulation circles  
r0 = 0.07;                      % radius of articulation circles 

t = 0.08;
    t1 = 2*pi*t;
    A  = 2*(l1*l3*cos(t1) - l3*l4);
    B  = 2*l1*l3*sin(t1);
    L  = l1^2 - l2^2 + l3^2 + l4^2;
    C  = L - 2*l1*l4*cos(t1);
    D  = A^2 + B^2 - C^2;    % discriminant of second-degree equation
    t3 = asin((-B*C + A*sqrt(D))/(A^2 + B^2));
    P1 = l1*[ cos(t1); sin(t1) ];
    x = P1(1) + r0*cos(t0);
    y = P1(2) + r0*sin(t0);
    Hp1 = patch(x, y, [ 0 0 0 ]);
    t2 = atan((l1*sin(t1) + l3*sin(t3) )/(l1*cos(t1)...
             + l3*cos(t3) - l4));
    P2 = P1 + l2*[ cos(t2); sin(t2) ];
    x = P2(1) + r0*cos(t0);
    y = P2(2) + r0*sin(t0);
    Hp2 = patch(x, y, [ 0 0 0 ]);
    Hp0 = plot([ P0(1) P1(1) P2(1) P3(1) ], [ P0(2) P1(2) P2(2) P3(2) ], 'k-' );
    set(Hp0, 'LineWidth', 1.5)
    text(P0(1), -0.3, 'P_0')
    text(P3(1)/1.05, -0.3, 'P_3')
    text(P1(1), (P1(2) - 0.2), 'P_1')
    text(P2(1), (P2(2) + 0.2), 'P_2')
    text((P0(1) + P3(1))/2, 0.13, 'l_4')
    text(l1/3, l1*sin(t1), 'l_1')
    tc = 0: t1/30: t1;
    rc = l1/3;
    xc = rc*cos(tc);
    yc = rc*sin(tc);
    plot(xc, yc, 'k-')
    text(l1/2.5, l1*sin(t1)/4, '\theta_1')
    plot([ P1(1)  (P1(1) + P2(1))/2.5 ], [ P1(2) P1(2) ],  'k-')
    tc = 0: t2/30: t2;
    rc = l2/10;
    xc = P1(1) + rc*cos(tc);
    yc = P1(2) + rc*sin(tc);
    plot(xc, yc, 'k-')
    text(l2/2.5, l2*sin(t2)/3.8, '\theta_2')  
    text((P1(1) + P2(1))/2.5, (P1(2) + P2(2))/2.2, 'l_2')
    text((P2(1) + P3(1))/2, (P2(2) + P3(2))/1.6, 'l_3') 
    plot([ l4 1.2*l4 ], [ 0 0 ], 'k-')
    tc = 0: t3/30: t3;
    rc = l3/10;
    xc = P3(1) + rc*cos(tc);
    yc = P3(2) + rc*sin(tc);
    plot(xc, yc, 'k-')
    text(1.06*l4, l3*sin(t3)/9, '\theta_3')  

t = 0.4;
    t1 = 2*pi*t;
    A  = 2*(l1*l3*cos(t1) - l3*l4);
    B  = 2*l1*l3*sin(t1);
    L  = l1^2 - l2^2 + l3^2 + l4^2;
    C  = L - 2*l1*l4*cos(t1);
    D  = A^2 + B^2 - C^2;      % discriminant of second-degree equation
    t3 = asin((-B*C + A*sqrt(D))/(A^2 + B^2));
    P1 = l1*[ cos(t1); sin(t1) ];
    x = P1(1) + r0*cos(t0);
    y = P1(2) + r0*sin(t0);
    Hp1 = patch(x, y, [ 0 0 0 ]);
    t2 = atan((l1*sin(t1) + l3*sin(t3) )/(l1*cos(t1) + l3*cos(t3) - l4));
    P2 = P1 + l2*[ cos(t2); sin(t2) ];
    x = P2(1) + r0*cos(t0);
    y = P2(2) + r0*sin(t0);
    Hp2 = patch(x, y, [ 0 0 0 ]);

    Hp0 = plot([ P0(1) P1(1) P2(1) P3(1) ], [ P0(2) P1(2) P2(2) P3(2) ], 'k-.' );
    set(Hp0, 'LineWidth', 1)
    r2 = l1;
    t2 = 0: pi/60: t1;
    x2 = r2*cos(t2);
    y2 = r2*sin(t2);
    plot(x2, y2, 'k:', 'LineWidth', 1.3)
        
hold off