%FIG7_5 Draws Figure 7.5, `To the definition of phasor'.
% Written by Adrian Biran for the book `What every engineer should know
% about MATLAB and Simulink'

% define parameters
r   = 1;                    % modulus
o   = 2;                    % angular frequency, rad/s
e   = pi/6;           % phase angle, rad/s
T   = 2*pi/o;         % period, s
dh = 3*r;               % horizontal distance between two origins 
dv = -2*r - 2*T;    % vertical distance between origins 
% define graph frame
plot([ -1.4*r 1.25*r ], [ 0 0 ], 'k-', [ 0 0 ], [ dv 1.5*r ], 'k-', [ 0.6*dh  (dh+ 1.6*T) ], [ 0 0 ],'k-')
axis equal
axis off
ht = text(-1.4*r, 0.2, '\Re');
set(ht, 'FontSize', 14)
ht = text(0.1, 1.4*r, '\Im');
set(ht, 'FontSize', 14)
ht = text((dh + 1.5*T), 0.25, 't');
set(ht, 'FontSize', 14)
ht = text((dh + 0.04*T), 0.25, '0');
set(ht, 'FontSize', 14)

hold on
plot([ dh dh ], [ -1.3*r 1.3*r ], 'k-')
% plot circle
a = 0: pi/90: 2*pi;
x = r*cos(a);
y = r*sin(a);
plot(x, y, 'k-')

% plot wave
t1 = -e/o;       % find zero of sine function
t   = t1: (t1 + 1.5*T)/50: 1.5*T;
z   = sin(o*t + e);
hp = plot((dh + t), z, 'k-');
set(hp, 'LineWidth', 1.5)
% find time of pi/4
t2 = (pi/4 - e)/o; 
% plot point corresponding to 45 degrees
point([ (dh + t2); cos(o*t2 + e) ], 0.05)        % point in time domain
Ph = r*exp(i*pi/4);
arrow([ 0; 0 ], [ real(Ph); imag(Ph) ], 0.08)
ht = text(r/4, r/1.5, 'P');
set(ht, 'FontSize', 14)
plot([ real(Ph)  (dh + t2) ], [ imag(Ph)  cos(o*t2 + e) ], 'k--')
xp = dh + 0.65*t2;
yp = cos(o*0.45*t2 + e);
% mark sine function
t3 = (3*pi/2 - e)/o;    % time of sin = -1
xp = dh + t3;
ht = text(xp, -1.5*r,  '\uparrow \rho sin(\omega t + \phi)');
set(ht, 'FontSize', 14)
ht = text(dh, -3*r,  'P = \rho e^{i(\omega t + \phi)}');
set(ht, 'FontSize', 14)

% plot cosine function
oc = (dv + 0.5*T);          % zero of cosine function
plot([ -1.25*r  1.25*r ], [ oc oc ], 'k-')
xc = cos(o*t + e);
zc = oc + t;                   % time axis of cosine function
hp = plot(xc, zc, 'k-');
set(hp, 'LineWidth', 1.5)
% plot point corresponding to 45 degrees
P45 = [ cos(o*t2 + e); (oc + t2) ]; 
point(P45, 0.05);
plot([ real(Ph) P45(1) ], [ imag(Ph) P45(2) ], 'k--')
% mark cosine function
ht = text(1.5*r,  oc, '\rho cos( \omega t + \phi)', 'Rotation', 90);
set(ht, 'FontSize', 14)
% show period
t4 = (pi/2 - e)/o;            % first sine maximum
t5 = (5*pi/2 - e)/o;        % second sine maximum
plot([ (dh + t4) (dh + t4) ], [ r 1.5*r ], 'k-') 
plot([ (dh + t5) (dh + t5) ], [ r 1.5*r ], 'k-')
t6 =dh + (t4 + t5)/2;
arrow([ t6; 1.4*r ], [ (dh + t4); 1.4*r ], 0.05)
arrow([ t6; 1.4*r ], [ (dh + t5); 1.4*r ], 0.05)
ht = text(t6, 1.7*r, 'T');
set(ht, 'FontSize', 14)
% show phase
t7 = (dh + t1);
plot([  t7 t7 ], [ -r 0 ], 'k-')
arrow([ (t7- T/6); -0.9*r ], [ t7; -0.9*r ], 0.05)
arrow([ (dh + T/5); -0.9*r ], [ dh; -0.9*r ], 0.05)
plot([ t7 dh ], [ -0.9*r -0.9*r ], 'k-')
ht = text((dh + T/8), -0.5*r, '\phi');
set(ht, 'FontSize', 14)

hold off