%FIG7_7  Draws Figure 7.7, `Phasor diagram of the mechanical system'.
% Written by Adrian Biran for the book `What every engineer should know
% about MATLAB and Simulink'

% define parameters
 m             = 2;
c              = 0.4;
k              = 0.1;
F0            = 1;
omega   = 0.3;  % natural frequency
omega0 = sqrt(k/m);
% calculate transfer function
T              = F0/(m*(omega0^2 - omega^2) + i*c*omega);
X0            = abs(T);                                 % response ampitude
r              =omega/omega0;
phi         = omega/omega0;  % phase
phideg = 180*phi/pi;

% calculate phasors 
spring    = k*T;
damping =  i*omega*c*T;    
inertia = -omega^2*m*T;
sum            = spring + damping + inertia - F0;
% define frame
plot([ -0.5 1.5 ], [ 0 0 ], 'k-', [ 0 0 ], [ -0.5 1.5 ], 'k-')
axis equal, axis off
ht = text( 1.4, 0.08, '\Re');
set(ht, 'FontSize', 16)
ht = text( 0.05, 1.4, '\Im');
set(ht, 'FontSize', 16)
hold on
% calculate points and plot arrows
O                 = [ 0; 0 ];
P1               = [ F0; 0 ];
arrow(O, P1, 0.05)
ht = text(P1(1)/2, 0.1, 'F_0');
set(ht, 'FontSize', 16)
P2 = [ real(inertia); imag(inertia) ];
arrow(O, P2, 0.05)
ht = text(P2(1)/2, P2(2)/2, 'inertia');
set(ht, 'FontSize', 16)
P3 = P2 + [ real(damping); imag(damping) ];
arrow(P2, P3, 0.05)
ht = text((P2(1) + P3(1))/1.8, P2(2)/1.2, 'damping');
set(ht, 'FontSize', 16)
P4 = P3 + [ real(spring); imag(spring) ];
arrow(P3, P4, 0.05)
ht = text(P4(1)/1.1, P3(2)/1.5, 'spring');
set(ht, 'FontSize', 16)

hold off
