function    TwoBarStatics


%TWOBARSTATICS   Generates Figure 10.11 in the book
% `What every engineer should know about MATLAB and Simulink'.
% GUI for the statics of a system consisting of 
%                                     a weight of 50 N hanging from the common point 
%                                     of two bars whose upper ends are conected to 
%                                     the ceiling by articulations.
%                                     Use the slider to change the position
%                                     of the weight relative to the upper
%                                     articulations of the two bars.
%                                     Written by Adrian Biran, June 2009.  

    % Initialize and hide the GUI during its construction
    f = figure('Visible', 'off');
      
    %%%%%%%  Construct the components %%%%%%%%%%%%%
    haxes = axes('Units', 'normalized',...
                                 'Position', [ 0.174 0.346 0.652 0.385 ]);
    % text boxes
    htext1   = uicontrol('Style', 'Text',...
                                                   'String', 'a, mm = ',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.26 0.82 0.16 0.038 ]);
    htext2   = uicontrol('Style', 'Text',...
                                                   'String', 'b, mm = ',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.609 0.82 0.16 0.038 ]);
    htext3   = uicontrol('Style', 'Text',...
                                                   'String', 'X-component',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.043 0.23 0.175 0.038 ]);
    htext4   = uicontrol('Style', 'Text',...
                                                   'String', 'Y-component',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.043 0.154 0.175 0.038 ]);
    htext5   = uicontrol('Style', 'Text',...
                                                   'String', 'Magnitude',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.043 0.077 0.175 0.038 ]);
    htext6   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.478 0.23 0.043 0.038 ]);
    htext7   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.478 0.154 0.043 0.038 ]);
    htext8   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.478 0.077 0.043 0.038 ]);
    htext9   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.783 0.23 0.043 0.038 ]);
    htext10 = uicontrol('Style', 'Text',...
                                                  'String', 'N',... 
                                                  'Units', 'normalized',...
                                                 'Position', [ 0.783 0.154 0.043 0.038 ]);
    htext11 = uicontrol('Style', 'Text',...
                                                  'String', 'N',... 
                                                  'Units', 'normalized',...
                                                  'Position', [ 0.783 0.077 0.043 0.038 ]);
    %slider control
    hslide  =  uicontrol('Style', 'slider',...
                                                   'BackgroundColor', [ 0.9 0.1 0.0 ],... 
                                                   'Min', 200,...
                                                   'Max', 1300,...
                                                   'SliderStep', [ 0.01 0.1 ],...
                                                   'Value', 500,...
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.26 0.885 0.489 0.038 ]); 
    % edit text boxes above figure
    hedit1 = uicontrol('Style', 'edit',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', num2str(get(hslide, 'Value')),...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.217 0.769 0.218 0.038 ]);
                                                 
    hedit2 = uicontrol('Style', 'edit',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', num2str(1500 - get(hslide, 'Value')),...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.769 0.218 0.038 ]);                                       
    % text boxes below the figure
                        % left
    hedit3 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.261 0.231 0.174 0.038 ]); 
    hedit4 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.261 0.154 0.174 0.038 ]);  
    hedit5 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ] ,...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.261 0.077 0.174 0.038 ]);
                            % right
    hedit6 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.231 0.174 0.038 ]); 
    hedit7 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.154 0.174 0.038 ]);  
    hedit8 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.077 0.174 0.038 ]);  
   
    %%%%%%%%  Name and make the GUI visible %%%%%%%%%%%%%
    set(f,  'NumberTitle', 'off',...
                   'Name', 'Two-bar statics');
    set(f, 'Visible', 'on')
   
end    