function Aliasing(k)

% ALIASING High frequency signals and aliasing.
% Written by Moshe Breiner for the book  `MATLAB for engineers'.
% Reused in the book `What every engineer should know about MATLAB and
% Simulink', Section 12.6.
% Example of running
%       k= 17; Aliasing(k)

T = 5;                                              % fundamental period
Np = 512;                                       % number of plotting points
t = linspace(0, T, (Np+1));     
t = t(1:Np);                                   % fine resolution time 
N = 16;                                             % number of sampling points
Ts = T/N;                                        % sampling interval
fs = 1/Ts;                                      % sampling frequency
ts = Ts*(0: (N - 1));                       % sampling instants
Nf = 1/(2*Ts);                                % Nyquist frequency
f = k/T;                                           % frequency of continuous signal 
x = sin(2*pi*f*t);                      % high-resolution signal
xs = sin(2*pi*f*ts);                 % sampling-resolution signal
% find fapp, such that f = n*fs*fapp
n = round(f/fs);
fapp = f - n*fs;
xa = sin(2*pi*fapp*t);
plot(t, x, 'k-', t, xa, 'k-', ts, xs, 'ko');
xlabel('t')
ylabel('Signal')
str1 = [ 'f_s = ', num2str(fs), ',  N_f = ', num2str(Nf) ];
str2 = [ 'k = ', num2str(k), ',  f = ', num2str(f)  ];
 str3 = [ 'f_{app} = ' , num2str(fapp) ];
 str = [ str1, ', ', str2, ', ', str3 ];
 title(str);
 
 