function    [ C, R ] = Circle3P(P1, P2, P3);

%CIRCLE3P   Given three points in the xOy plane, this function finds the
%                        center and the  radius of the circle passing
%                        through them. A varint of Example 3.2 in the book
%                        `What every engineer should know about MATLAB and
%                        Simulink' written by Adrian Biran.
%                        Input arguments: coordinates of three points
%                        given as three column vectors, e.g
%                        P1 = [ x1, y1, z1 ];
%                        Output arguments: coordinates of center
%                        given as C = [ Cx; Cy ];
%                        circle radius, R

% check that the poins are not collinear
if cross([ (P2 - P1); 0 ], [ (P3 - P1); 0 ]) == 0
    errordlg( 'Given points are collinear', 'Input error')
end
% build matrix of coefficients
A = [ P1(1),  P1(2),  -1;
          P2(1), P2(2),  -1;
          P3(1), P3(2),  -1 ];
% build free vector
B = [ P1(1)^2 + P1(2)^2; P2(1)^2 + P2(2)^2; P3(1)^2 + P3(2)^2 ];
Z = A\B;
C = [ Z(1)/2; Z(2)/2 ];
R = sqrt(C(1)^2 + C(2)^2 - Z(3));
