function    [ c, C, r ] = Circle3PA(P1, P2, P3)

%CIRCLE3PA Given three non-collinear points, Circle3PA
%                        Finds the equation, the radius and the 
%                        center of the circle passing through them.
%                        The solution follows Anton and Rorres, 2005
%                        See Example 3.2 of the book
%                        `What every engineer should know about MATLAB and
%                        Simulink' written by Adrian Biran.

% check that the poins are not collinear
if cross([ (P2 - P1); 0 ], [ (P3 - P1); 0 ]) == 0
    errordlg( 'Given points are collinear', 'Input error')
end
% Separate variables
x1 = P1(1); y1 = P1(2);
x2 = P2(1); y2 = P2(2);
x3 = P3(1); y3 = P3(2);
%  Equation of coefficients
A = [ (x1^2 +y1^2)   x1  y1  1 
         (x2^2 +y2^2)   x2  y2  1 
         (x3^2 +y3^2)   x3  y3  1 ] ;
% Calculate the coefficients of the equation of the circle
c     = zeros(1, 4);            % allocate space for array of coefficients
c(1) =  det(A(1:3, 2:4));
c(2) = -det([ A(1:3, 1) A(1:3, 3:4) ]);
c(3) =  det([ A(1:3, 1:2) A(1:3, 4) ]);
c(4) =  det([ A(1:3, 1:3) ]);
% calculate coordinates of center of circle
C = [ -c(2)/(2*c(1)); -c(3)/(2*c(1)) ];
r = norm(C - P1);