%CONFMAP  First example of conformal mapping,  Section 7.7 of the book
%                     `What every engineer should know about MATLAB and
%                     Simulink'. Written by Adrian Biran.
%                     This is the black-and-white variant of the script file
%                      ConfMap; it produces Figure 7.4 in the book.
%                     Circles are mapped onto ellipses, and straight lines
%                     onto hyperbolas

%%%%%%%%%%%%%%%%%% z-plane %%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 1)
% plot coordinate axes
plot([ -10 10 ], [ 0 0 ], 'k-', [ 0 0 ], [ -17 17 ], 'k-')
axis equal
ht = title('z-plane');
set(ht, 'FontSize', 16)
hl = xlabel('\Re');
set(hl, 'FontSize', 14)
hl = ylabel('\Im');
set(hl, 'FontSize', 14)
% define curves in the z-plane
x1 = linspace(-5, 0);
x2 = linspace(0, 5);
% straight lines
a   = 0;        % initialize slope of straight lines
y1 = zeros(6, length(x1)); % allocate space
y2 = zeros(6, length(x2)); 
% plot curves in the z-plane
% circles
t   = 0: 2.5: 360;                  % degrees
r   = 0;                                   % initiaize circle radii  
xc = zeros(6, length(t)); % allocate space
yc = zeros(6, length(t)); 
hold on
for k = 1:5
    % straight lines
    a = a + 30;                       % increase slope by 15 degrees
    y1(k, :) =  tand(a)*x1;  % left-hand part of straight lines
    text(x1(10), y1(k, 10), num2str(k))
    plot(x1, y1(k, :), 'k-')
    y2(k, :) = tand(a)*x2;   % right-hand part of straight lines
    plot(x2, y2(k, :), 'k')
    % circles
    r  = r + 2;                         % increase ircle radius by 1
    xc(k, :) = r*cosd(t);
    yc(k, :) = r*sind(t);
    plot(xc(k, :), yc(k, :), 'k-') 
    % text(xc(10), yc(k, 10),  num2str(k) )
end 
x1 = repmat(x1, 6, 1);
x2 = repmat(x2, 6, 1);
z1 = x1 + y1*i;
z2 = x2 + y2*i;
z3 = xc + yc*i;
hold off
%%%%%%%%%%%%% CONFORMAL MAPPING %%%%%%%%%%%%%%
w1 = (z1 + 1./z1)/2;
w2 = (z2 + 1./z2)/2;
%%%%%%%%%%%%%% z-plane %%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 2)
plot([ -5 5 ], [ 0 0 ], 'k-', [ 0 0 ], [ -10 10 ], 'k-')     % coordinate axes
axis equal
ht = title('w-plane');
set(ht, 'FontSize', 16)
hl = xlabel('\Re');
set(hl, 'FontSize', 14)
hl = ylabel('\Im');
set(hl, 'FontSize', 14)
hold on
point([ -1; 0 ], 0.15)
point([ 1; 0 ], 0.15)
w3 = (z3 + 1./z3)/2;
for k= 1:5
    plot(real(w1(k, :)), imag(w1(k, :)), 'k-')
    text(real(w1(k, 2)), imag(w1(k, 2)), num2str(k))
    plot(real(w2(k, :)), imag(w2(k, :)), 'k-')
    text(real(w2(k, end)), imag(w2(k, end)), num2str(k))
    plot(real(w3(k, :)), imag(w3(k, :)), 'k-')
 end    
hold off