%DCCIRCUIT Example of DC circuit solved by different methods
% in Section 3.4 of the book `What every engineer should know about
% MATLAB and Simulink'.
% Written by Adrian Biran

% %%%%% KIRCHOFF'S LAWS%%%%%
disp('KIRCHOFF''s LAWS')
% define array of resistance values
R = [ 20 40 20 40 40 10 ];        % ohm
% calculate conductances
C = 1./R;                               % S
% define voltage sources
V1 = 9;                                  % V
V2 = 12;                                % V
% define matrix of coefficients
A = [ -1      -1      1        0        0       0
          0        1      0       -1        1       0
          0        0      0        1       -1       1  
          R(1)   0      R(3)    0        0       0
          0        0      0        R(4)   R(5)   0
          0        R(2) R(3)    R(4)    0      -R(6) ];
% define vector of voltage sources
S = [ 0; 0; 0; V1; V2; 0 ];
% calculate branch currents
I1 = A\S                                 % V
disp('Check sum of currents at node 0')
I1(1) - I1(3) - I1(6) 
disp('Check sum of currents at node 1')
-I1(1) - I1(2) + I1(3)
disp('Check sum of currents at node 2')
I1(2) - I1(4) + I1(5)
disp('Check sum of currents at node 3')
I1(4) - I1(5) + I1(6)
disp('Check Kirchoff in outer loop')
R(1)*I1(1) - R(2)*I1(2) + R(5)*I1(5) + R(6)*I1(6) - V1 - V2 
%%%%% Method of loop currents %%%%%
disp('METHOD OF LOOP CURRENTS')
disp('LOOP CURRENTS')
% define matrix of resistances
RM = [ (R(1) +R(3))  -R(3)  0
           -R(3)  (R(2) + R(3) + R(4) + R(6))  -R(4)
           0  -R(4)  (R(4) + R(5)) ];
% define vector of voltage sources
VV = [ V1; 0; V2 ];
% calculate loop currents
J = RM\VV
% calculate branch currents
I2     = zeros(5, 1);
I2(1) = J(1);
I2(2) = -J(2);
I2(3) = J(1) - J(2);
I2(4) = J(3) - J(2);
I2(5) = J(3);
I2(6) = J(2);
I2
% compare with previous solution
I1 - I2
disp('Check Kirchoff in outer loop')
R(1)*I2(1) - R(2)*I2(2) + R(5)*I2(5) + R(6)*I2(6) - V1 - V2 
