% Example12_3, Identification of the frequencies that contain most power
% Written by Moshe Breiner for Example 16.5 in `MATLAB for engineers'.
% Reused in `What every engineer should know about MATLAB and Simulink'
% with the kind permission of Pearson Education.
% for Example 12.3. Produces Figures 1.5.

T = 5;
N = 512;
t = linspace(0, T, (N + 1));
t = t(1:N);
x1 = 2*t/T - 1/2;
x2 = 2*(T - t)/T - 1/2;
x = min(x1, x2);        % triangular signal
plot(t ,x, 'k-')
%%%%%%%%%% and construct power spectrum
b = 1:N;            % bin sequential number
X = fft(x);
Ts= T/N;           % sampling interval 
fs = N/T;           % sampling frequency
frs = (b - 1)/T; % equal to (b - 1)/N*fs
pow = X.*conj(X)/N;
% verify Parseval's equality.
sum(pow),   norm(x)^2 
% to identify frequencies that contain lagest power
disp('Effect of sort')
[ spow, spos ] = sort(pow);
% indices of four frequencies that contain most
m = 4; spos(N: -1: (N - m + 1))
% construct approximate signal
%X4 = zeros(X); % allocate space for approximated X
h = [ 512 2 510 4 ];
X4(h) = X(h);   % copy the bins that
% percentage of power in the four
perc = 100*(norm(X4)/norm(X))^2
% shows how closely
x4 = ifft(X4);
hold on
plot(t, x4, 'k--')
grid 
xlabel('t')
ylabel('Signal')
legend('Triangular signal', 'Approximation')

