 function    g = FourLinkMovie(l1, l2, l3, l4)

 %FOURLINK   Simulation of four-link mechanism
 %           The input consists of the lengths of the four bars,
 %           l1, l2,l3, l4, where l4 connects the two fixed
 %           points P0 and P3.Internal variables are the angles
 %           t1, t2, t3. As an example call the function with
 %           FourLink(1, 3, 3, 4)
 %           Developed by Adrian Biran for Subsection 7.9.4 in
 %          `What every engineer should know about MATLAB and Simulink'.

 P0 = [  0; 0 ]; P3 = [ l4; 0 ];
 % define frame
 Hp = plot([ 0 l4 ], [ 0 0 ], 'k-');
 set(Hp, 'LineWidth', 1.5)
 axis([ -1.1*l1 1.1*(l4 + l3) -1.1*l3 1.1*l3 ])
 axis equal, axis off

 hold on
 point(P0, 0.07)
 point(P3, 0.07)
 t0  = 0: pi/30: 2*pi; % parameter of articulation circles
 r0  = 0.07;                     % radius of articulation circles
 a1  = 0: pi/60: pi;     % parameter of circular trajectories
 x1  = l1*cos(a1);       
 y1  = l1*sin(a1);
 hp = plot(x1, y1, 'r--');
 set(hp, 'LineWidth', 1.3)
 a3  = pi/2: pi/60: pi;
 x3  = P3(1) + l3*cos(a3);       
 y3  = P3(2) + l3*sin(a3);
 hp = plot(x3, y3, 'r--');
 set(hp, 'LineWidth', 1.3)

 for k = 1:9
      t = (k -1)/8;
     if t > 0
         delete(Hp0)
         delete(Hp1)
         delete(Hp2)
     end
     t1 = pi*t;
     A  = 2*(l1*l3*cos(t1) - l3*l4);
     B  = 2*l1*l3*sin(t1);
     L  = l1^2 - l2^2 + l3^2 + l4^2;
     C  = L - 2*l1*l4*cos(t1);
     D  = A^2 + B^2 - C^2 ;% discriminant of 2nd-degree equation
     t3 = asin((-B*C + A*sqrt(D))/(A^2 + B^2));
     P1 = l1*[ cos(t1); sin(t1) ];
     x = P1(1) + r0*cos(t0);
     y = P1(2) + r0*sin(t0);
     Hp1 = patch(x, y, [ 0 0 0 ]);
     t2 = atan((l1*sin(t1) + l3*sin(t3) )/(l1*cos(t1)...
          + l3*cos(t3) - l4));
     P2 = P1 + l2*[ cos(t2); sin(t2) ];
     x = P2(1) + r0*cos(t0);
     y = P2(2) + r0*sin(t0);
     Hp2 = patch(x, y, [ 0 0 0 ]);

     Hp0 = plot([ P0(1) P1(1) P2(1) P3(1) ],...
                [ P0(2) P1(2) P2(2) P3(2) ], 'k-' );
     set(Hp0, 'LineWidth', 1.5)
    pause(0.5)
    M(k) = getframe;
 end
 hold off
 movie(M, -10)