% MSDPLOT  Plots  Figure 11.24, `Damped oscillations of a
% mass-spring-dashpot system'. Written by Adrian Biran for the book
% `What every engineer should know about MATLAB and Simulink'.

% define parameters
m = 2;               % mass, kg
c = 0.4;            % damping, Ns/m
k = 0.1;            % spring constant, N/m

% calculate solutions of characteristic equation
d           = sqrt(c^2 - 4*m*k);          % discriminant
s1         = (-c + d)/(2*m);
s2         = (-c - d)/(2*m);
x0         = 0.2;                                       % initial position, m
xdot0 = 0;                                          % initial velocity, m/s
AA         = [ 1 1; s1 s2 ];                      % coeficient matrix of initial conditions
BB         = [ x0; xdot0 ];                    % free vector of initial conditions  
XX         = AA\BB;
A            = XX(1);
B            = XX(2);
t            = 0:50;
x            = A*exp(s1*t) + B*exp(s2*t);
hp         = plot(t, x, 'k-');
grid
set(hp, 'LineWidth', 2)
set(gca,  'XTick', 0: 10: 50,...
                    'XTickLabelMode', 'manual',...
                    'FontUnits', 'point',...
                    'FontSize', 18,...
                    'XTickLabel', 0: 10: 50,...
                    'YTick', -0.05: 0.05: 0.2,...
                    'YTickLabelMode', 'manual',...
                    'FontUnits', 'point',...
                    'FontSize', 18,...
                    'YTickLabel', -0.05: 0.05: 0.2)
ht = xlabel('t, s');
set(ht, 'FontSize', 22)
ht = ylabel('x, m');
set(ht, 'FontSize', 22)
tt         = [ 'm = ' num2str(m) ' kg, c = ' num2str(c) 'N s m^{-1}, k = ' num2str(k) 'N m^{-1}' ];
ht         = title(tt);
set(ht, 'FontSize', 22)