%PROOFROT  Proof of rotation matrix
%                    Developed by Adrian Biran for Subsection 3.9.1, 
%                    in `What every engineer should know about MATLAB and
%                    Simulink'. Plots a drawing similar to Figure 3.17. 

% define frame
plot([ -1 4 ], [ 0 0 ], 'k-', [ 0 0 ], [ -1 4 ], 'k-')
axis equal, axis off
ht         = xlabel('x');
set(ht, 'FontSize', 16)
ht         = ylabel('y');
set(ht, 'FontSize', 16)
hold on
x1          = 3;
y1          = 2;
r            = norm([ x1; y1 ]);
hp = plot([ x1 x1 ], [ y1 0 ], 'k--');
set(hp, 'LineWidth', 1.3)
ht = text(x1, -0.2, 'x_1');
set(ht, 'FontSize', 14)
hp = plot([ x1 0 ], [ y1 y1 ], 'k--');
set(hp, 'LineWidth', 1.3)
ht = text( -0.3, y1,  'y_1');
set(ht, 'FontSize', 14)
x2          = 2;
t            = 0: 2.5: 90;
xc         = r*cosd(t);
yc         = r*sind(t);
hp         = plot(xc, yc,  'k-.');
set(hp, 'LineWidth', 1.3)
point([ x1; y1 ], 0.03)
ht         = text(1.01*x1, 1.05*y1, 'P_1');
set(ht, 'FontSize', 16)

h1 = @(alpha) x1*cosd(alpha) - y1*sind(alpha) - x2;
h2 = @(alpha) -x1*sind(alpha) - y1*cosd(alpha);
disp('Rotation angle, alpha')
alpha = newton(h1, h2, 1)
disp('y2')
y2          = x1*sind(alpha) + y1*cosd(alpha);
point([ x2; y2 ], 0.03)
ht         = text(1.01*x2, 1.05*y2, 'P_2');
set(ht, 'FontSize', 16)
hp = plot([ x2 x2 ], [ y2 0 ], 'k--');
set(hp, 'LineWidth', 1.3)
ht = text(x2, -0.2, 'x_2');
set(ht, 'FontSize', 14)
hp = plot([ x2 0 ], [ y2 y2 ], 'k--');
set(hp, 'LineWidth', 1.3)
ht = text( -0.3, y2,  'y_2');
set(ht, 'FontSize', 14)
% show common radius
arrow([ 0; 0 ], [ x1; y1 ], 0.1)
alpha = atand(y1/x1);
ht = text(x1/2, y1/1.6, 'r', 'Rotation', alpha);
set(ht, 'FontSize', 14)
r1 = 1;
t1 = 0: alpha;
u1 = r1*cosd(t1);
v1 = r1*sind(t1);
plot(u1, v1, 'k-')
ht = text(1.1, v1(end)/2, '\alpha');
set(ht, 'FontSize', 14)
beta = atand(y2/x2);
r2 = 1.5;
t2 = alpha: beta;
u2 = r2*cosd(t2);
v2 = r2*sind(t2);
plot(u2, v2, 'k-')
ht = text(1.15, (v2(1) + v2(end))/1.8, '\theta');
set(ht, 'FontSize', 14)
% show common radius
arrow([ 0; 0 ], [ x2; y2 ], 0.1)
ht = text(x2/2, y2/1.6, 'r', 'Rotation', beta);
set(ht, 'FontSize', 14)

hold off