function [ t, w ] = RK2fxeq(odefun, tspan, w0);

% This is the implementation of the second order
%  Runge-Kutta algorithm for functions. The user defines:
%   - the name of the odefile F (scalar function!)
%   - the points of integration, tspan
%   - the initial state, w0
%  The outputs
%       -t, equal to tspan
%        w, solution
%  Calling syntax [ t, w ] = RK2fxeq('F', tspan, w0);
% Written by Moshe Breiner for `MATLAB for Engineers'.
% Reused in `What every engineer should know about MATLAB and Simulink'.
% See Subsection 9.4.3 in this book.


 % define parameters of integration routine
la1 = 1/4;
la2 = 3/4;
al   = 2/3;
l = length(tspan);
t = zeros(l, 1);        % allocate space for time
w = zeros(l, 1);        % allocate space for solution
% assign initial conditions
t(1) = tspan(1);
w(1) = w0;
% start cycle
for i = 1: (l - 1)
    T = tspan(i);       % initial time of the cycle
    W = w(i);               % inital value of the cycle
    del_t = tspan(i+1) - tspan(i);
    k1 = feval(odefun, T, W);
    k2 = feval(odefun, T+al*del_t, W+al*k1*del_t);
    k   = la1*k1 + la2*k2;
    t(i+1) = tspan(i+1);
    w(i+1) = W+k*del_t;
end    