%RLCSERIES2  solves the series RLC circuit analyzed in Subsection 7.8.3. 
% of `What every engineer should know about MATLAB and Simulink'.  
% Plots Figure 7.11 and, after pressing Enter, Figure 7.10.
% Variant with European voltage and frequency values.
% Written by Adrian Biran.

clear all
% define circuit parameters
u0    = sqrt(2)*(220)
R      = 50;                    % ohms
L      = 100/10^3;         % Henri
C      = 400/10^6;         % Farad
f      = 50;                    % voltage frequency, Hertz
om    = 2*pi*f          % voltage angular frequency, rad/s
% calculate series impedance
imp = om*L - 1/(om*C)
Z      = R + i*imp     % ohm
TF   = u0/Z
i0    = abs(TF)           % current amplitude
phi = angle(TF)       % current phase, rad
% plot voltage and current
T       = 2*pi/om;          % period, s 
t       = 0: T/50: 3.5*T; % time scale, s
U       = u0*sin(om*t);
arg  = om*t + ones(size(t))*phi;
I       = i0*sin(arg);
subplot(2, 1, 1)
    plot(t, U, 'k-'), grid
    ylabel('Voltage, V')
subplot(2, 1, 2)    
    plot(t, I, 'k-'), grid
    xlabel('t, s')
    ylabel('Current, A')
% print -deps RLCtimeStory.eps    
pause    
hold off
%%%%%%%%%%%%%%%% phasor diagram %%%%%%%%%%%% 
clf
% define frame
I        = i0*exp(j*phi)
vR      = R*I
vL      = j*om*L*I
vC      = -j*I/(om*C)
vR + vL + vC - u0
b         =  max([ real(vR),  real(vL), real(vC) ]);
h         = max([ imag(vR), imag(vL), imag(vC) ]);
plot([ -0.2*b 1.6*b ], [ 0 0 ], 'k-', [ 0 0 ], [ -0.1*h  h ], 'k-')
axis equal, axis off
% axis([ -0.25*b 1.7*b -0.1*h 1.2*h ])
ht = text(1.6*b, 0.05*h, '\Re');
set(ht, 'FontSize', 16);
ht = text(0.02*b, h, '\Im')
set(ht, 'FontSize', 16);
hold on
O         = [ 0; 0 ]
PL      = [ real(vL); imag(vL) ]
arrow(O, PL, 1.3)
ht = text(0.5*PL(1)/2, PL(2)/2,  'v_L');
set(ht, 'FontSize', 16);
PR      = PL + [ real(vR); imag(vR) ]
arrow(PL, PR, 1.3)
ht = text((PL(1) + PR(1))/2, (PL(2) + PR(2))/1.8, 'v_R');
set(ht, 'FontSize', 16);
PC      = PR + [ real(vC); imag(vC) ]
arrow(PR, PC, 1.3)
ht = text((PR(1) + PC(1))/1.95, (PR(2) + PC(2))/1.8, 'v_C');
set(ht, 'FontSize', 16);
arrow(O, [ u0; 0 ], 1.3)
ht = text(u0/2, 0.08*h, 'u_0');
set(ht, 'FontSize', 16);

hold off 
