%ROTEXAMPLE  Example of rotation in homogeneous coordinates
% analyzed in Subsection 2.5.3 of the book
% `What every engineer should know about MATLAB and Simulink'.
% Produces Figure 2.21.
% Written by Adrian Biran.

% define triangle in homogeneous coordinates
P = [ 1 2 5 1; 2 4 3 2 ; 1 1 1 1];
% define parameters of transformations
theta = 30;     % degrees
% define rotation matrix
Tr = [ cosd(theta)  -sind(theta)    0; sind(theta)  cosd(theta) 0; 0    0   1];
%%%%%%%%%%%%%% %%%%% Rotation  %%%%%%%%%%%%%%%%%%%
Q = Tr*P
%%%%%%%%%%%%%% %%%%%  Plot  %%%%%%%%%%%%%%%%%%%%
% define frame
plot([ -1 7 ], [ 0 0 ], 'k-', [ 0 0 ], [ -1 6 ], 'k-');
axis equal
ht = xlabel('x');
set(ht, 'FontSize', 16)
ht = ylabel('y');
set(ht, 'FontSize', 16)
ht = text(0.15, 0.25, 'O');
set(ht, 'FontSize', 14)
hold on
% plot initial triangle
hp = plot(P(1,:), P(2,:), 'k-');
set(hp, 'LineWidth', 1.5)
ht = text(0.8*P(1,1), 0.8*P(2, 1), 'P_1');
set(ht, 'FontSize', 14)
ht = text(1.05*P(1, 2), 1.05*P(2, 2), 'P_2');
set(ht, 'FontSize', 14)
ht = text(1.05*P(1, 3), P(2, 3), 'P_3');
set(ht, 'FontSize', 14)
% plot transformed triangle
hp = plot(Q(1,:), Q(2,:), 'k--');
set(hp, 'LineWidth', 1.3)
ht = text(4*Q(1,1), 0.85*Q(2, 1), 'Q_1');
set(ht, 'FontSize', 14)
ht = text(2.5*Q(1, 2), 1.06*Q(2, 2), 'Q_2');
set(ht, 'FontSize', 14)
ht = text(1.05*Q(1, 3), Q(2, 3), 'Q_3');
set(ht, 'FontSize', 14)
%%%%%%%%%%%%%%%%%% checks for exercises %%%%%%%%%%%%%%
% distance between two points
disp('distance from P1 to P2')
norm(P(1:2, 2) - P(1:2, 1))
disp('distance from Q1 to Q2')
norm(Q(1:2, 2) - Q(1:2, 1))
% angle of rotation
disp('degrees P1 was rotated by')
acosd(dot(P(1:2, 1), Q(1:2, 1))/(norm(P(1:2, 1))*norm (Q(1:2, 1))))

hold off