% SPLINETRIAL   Experiments with the MATLAB spline.
% Written by Adrian Biran for Section 4.5 of the book
% `What every engineer should know about MATLAB and Simulink'.

% enter station points
x   = [ -9.1361 -7.7103 -6.1394 -3.9366 -2.5037 -1.5628 -0.9030 ...
 -0.5933 -0.4555  ];
y   = [ 11.0276  8.6891  7.0619  5.3533  4.1221  2.8927  1.6643 ...
  0.6349  0.1994   ];
% plot given points
plot(x, y, 'ro'), grid
axis equal
xlabel('Half-breadth')
ylabel('Depth')
% print -deps SplineTrial1.eps
pause
%%%%%%%%%%%%%%%  polynomial interpolation %%%%%%%%%%%%%%%%
n   = length(x);
m   = n - 1;
% coefficients of polynomial interpolation, degree m
c   = polyfit(x, y, m)
xi = x(1): (x(n) - x(1))/30: x(n);  % interpolation scale
yi = polyval(c, xi);        % polynomial interpolation
plot(x, y, 'ro', xi, yi, 'k-'), grid
axis equal
title([ 'Polynomial fit, degree  '  num2str(m) ])
xlabel('Half-breadth')
ylabel('Depth')
% print -deps SplineTrial2.eps
pause
%%%%%%%%%%%%%%%% spline interpolation % %%%%%%%%%%%%%%%%%%
yi = spline(x, y, xi);
% plot MATLAB spline
plot(x, y, 'ro', xi, yi, 'k-')
axis equal
title('Cubic spline interpolation')
xlabel('Half-breadth')
ylabel('Depth')
% print -deps SplineTrial3.eps
pause
%%%%%%%%%%%%% Write own spline and caculate area under it %%%%%%%%%%%
hold on

% find details of MATLAB spline
pp = spline(x, y);
[breaks,coefs,l,k,d] = unmkpp(pp)

I   = 0 ;                               % initialize integral  
% loop over spline segments
for n = 1:l 
    % create interpolating scale
    xi = breaks(n): 0.1: breaks(n+1);
    % calculate interpolated points
    yi = coefs(n, 1)*(xi - breaks(n)).^3 + coefs(n, 2)*(xi - breaks(n)).^2 + ...
              coefs(n, 3)*(xi- breaks(n)) + coefs(n, 4);
    % calculate area under the spline curve
    dx = breaks(n+1) - breaks(n);
    I0  = coefs(n, 1)*dx^4/4 + coefs(n, 2)*dx^3/3 + coefs(n, 3)*dx^2/2 + coefs(n, 4)*dx;
    % plot interpolated spline in red, over the MATLAB spline in black
    plot(xi, yi, 'r-') 
    I   = I + I0;
end
% end loop over spline segments
t = [ 'Cubic spline and its integral, \int ydx =  ' num2str(I, 2) ] ;
title(t) 
legend('Given points', 'MATLAB spline', 'My spline')
hold off
