function    [ r1 r2 R1 R2 ] = Stat1FigFun(a)

%STAT1FIGFUN     prints the figure of the GUI TwoBarStatics
%                                  The input argument a is given in mm, as usual
%                                  in Mechanical-Engineering drawings. 
%                                  The output arguments are measured in N.
%                                  Written by Adrian Biran for Example 2.5 in the book
% `What every engineer should know about MATLAB and Simulink'.

% Define parameters for drawing
ad = a/10;
b    = 150 - ad;
c    =   50;
ha = 110;       % higher articulations z
w    =   50;       % length of W vector, N
% define articulations;
A    = [ 30; ha ];
B    = [ (30+ ad); (ha -c) ];
C    = [ (30 + 150); ha ];
% plot something
pline([ A B C ], 1, 'k', '-')
axis([ 0 190 0 135 ])
axis equal, axis off
hold on
% plot ceiling
hp = plot([ 20 190 ], [ 115 115 ], 'k-');
set(hp, 'LineWidth', 1.5)
plot([ 20 22.5 ], [ 117.5 120 ], 'k-')

% plot articulations
point(A, 1)     % first articulation from left        
plot([ 25 30 35 25 30 ], [ 115 110.5 115 115 110.5 ], 'k-')
point(B, 1)     % secod articulation from left
x0 = 20;            % initialize hatching
for k = 1:67
    plot([ x0 (x0 + 5) ], [ 115 120 ], 'k-')
    x0 = x0 + 2.5;
end
plot([ 187.5 190 ], [ 115 117.5 ], 'k-')    % end hatching
point(C, 1)     % third articulation from left
plot([ 175 180 185 175 180 ], [ 115 110.5 115 115 110.5 ], 'k-')
% plot hanging weight
arrow(B, [ B(1); (B(2) - w) ], 2.1)
ht = text((B(1) + 2), 30, 'W = 50 N');
set(ht, 'FontSize', 14)

% Plot inverse of W vector
arrow(B, [ B(1); (B(2) + w) ], 1.3)
text((B(1) + 3), (B(2) + w/2), '-W')
% calculate angles
alpha = atand(ad/c);
beta    = atand(b/c);
gamma    = 180 - alpha - beta;
% calculate magnitudes of tension vectors
r1          = sind(beta)*w/sind(gamma);
r2          = sind(alpha)*w/sind(gamma);
% define tension vectors  % two-dimensional
R1          = r1*[ -sind(alpha); cosd(alpha) ];
R2          = r2*[  sind(beta); cosd(beta) ];
% coordinates of vector extremities
L1          = B + R1;
arrow(B, L1, 1.6)
ht         = text((L1(1) - 8), (L1(2) - 8), 'R_1');
set(ht, 'FontSize', 12, 'FontWeight', 'bold')
L2          = B + R2;
ht         = text((L2(1) + 5), (L2(2) - 4), 'R_2');
set(ht, 'FontSize', 12, 'FontWeight', 'bold')
arrow(B, L2, 1.6)
% dimensions
plot([ 30 30 ], [ 115 126 ], 'k-')
plot([ B(1) B(1) ], [ 115 126 ], 'k-')
plot([ 180 180 ], [ 115 126 ], 'k-')
arrow([ (A(1) + B(1))/2; 125 ], [ 30; 125 ], 0.8)
arrow([ (A(1) + B(1))/2; 125 ], [ B(1); 125 ], 0.8)
ht = text((30 + ad/2), 129, 'a');
set(ht, 'FontSize', 10)
arrow([ (B(1) + C(1))/2 ; 125 ], [ B(1); 125 ], 0.8)
arrow([ (B(1) + C(1))/2; 125 ], [ C(1); 125 ], 0.8)
ht = text((B(1) + C(1))/2, 129, 'b');
set(ht, 'FontSize', 10)
plot([ 4 30 ], [ 110 110 ], 'k-')
plot([ 4 B(1) ], [ 60 60 ], 'k-')
arrow([ 5; 85 ], [ 5; 110 ], 0.8)
arrow([ 5; 85 ], [ 5; 60 ], 0.8)
ht = text(0, 65, 'c = 500', 'rotation', 90);
set(ht, 'FontSize', 10)
% plot parallelogram of forces
pline([ L1 [ B(1); (B(2) + w) ] ], 1, 'r', '--')
pline([ L2 [ B(1); (B(2) + w) ] ], 1, 'r', '--')

hold off