function    TwoBarStatics4
%TWOBARSTATICS  GUI for the statics of a system consisting of 
%                                     a weight of 50 N hanging from the common point 
%                                     of two bars whose upper ends are conected to 
%                                     the ceiling by articulations.
%                                     Use the slider to change the position
%                                     of the weight relative to the upper
%                                     articulations of the two bars.
%                                     Written by Adrian Biran for Taylor & Francis,
%                                     June 2009.  

    % Initialize and hide the GUI during its construction
    f = figure('Visible', 'off');                          
           
    %%%%%%%  Construct the components %%%%%%%%%%%%%
    haxes = axes('Units', 'normalized',...
                                  'Position', [ 0.174 0.346 0.652 0.385 ]);
    % text boxes
    htext1   = uicontrol('Style', 'Text',...
                                                   'String', 'a , mm, = ',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.26 0.82 0.16 0.038 ]);
    htext2   = uicontrol('Style', 'Text',...
                                                   'String', 'b, mm = ',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.609 0.82 0.16 0.038 ]);
    htext3   = uicontrol('Style', 'Text',...
                                                   'String', 'X-component',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.043 0.23 0.175 0.038 ]);
    htext4   = uicontrol('Style', 'Text',...
                                                   'String', 'Y-component',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.043 0.154 0.175 0.038 ]);
    htext5   = uicontrol('Style', 'Text',...
                                                   'String', 'Magnitude',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.043 0.077 0.175 0.038 ]);
    htext6   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.478 0.23 0.043 0.038 ]);
    htext7   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.478 0.154 0.043 0.038 ]);
    htext8   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.478 0.077 0.043 0.038 ]);
    htext9   = uicontrol('Style', 'Text',...
                                                   'String', 'N',... 
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.783 0.23 0.043 0.038 ]);
    htext10 = uicontrol('Style', 'Text',...
                                                  'String', 'N',... 
                                                  'Units', 'normalized',...
                                                 'Position', [ 0.783 0.154 0.043 0.038 ]);
    htext11 = uicontrol('Style', 'Text',...
                                                  'String', 'N',... 
                                                  'Units', 'normalized',...
                                                  'Position', [ 0.783 0.077 0.043 0.038 ]);
    %slider control
    hslide  =  uicontrol('Style', 'slider',...
                                                   'BackgroundColor', [ 0.9 0.1 0.0 ],... 
                                                   'Min', 200,...
                                                   'Max', 1300,...
                                                   'SliderStep', [ 0.01 0.1 ],...
                                                   'Value', 500,...
                                                   'Units', 'normalized',...
                                                   'Position', [ 0.26 0.885 0.489 0.038 ],...
                                                   'Callback', @slider_callback); 
    % edit text boxes above figure
    hedit1 = uicontrol('Style', 'edit',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', num2str(get(hslide, 'Value')),...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.217 0.769 0.218 0.038 ],...
                                                 'Callback', @edittext_callback);
    hedit2 = uicontrol('Style', 'edit',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', num2str(1500 - get(hslide, 'Value')),...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.769 0.218 0.038 ],...
                                                 'Callback', @edittext_callback2);
    % text boxes below the figure
                        % left
    hedit3 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.261 0.231 0.174 0.038 ]); 
    hedit4 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.261 0.154 0.174 0.038 ]);  
    hedit5 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ] ,...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.261 0.077 0.174 0.038 ]);
                            % right
    hedit6 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.231 0.174 0.038 ]); 
    hedit7 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.154 0.174 0.038 ]);  
    hedit8 = uicontrol('Style', 'text',...
                                                 'BackgroundColor', 'y',... 
                                                 'String', [ ],...
                                                 'Units', 'normalized',...
                                                 'Position', [ 0.565 0.077 0.174 0.038 ]);  
    [ r1 r2 R1 R2 ] = Stat1FigFun(500);
    %%%%%%%%  Name and make the GUI visible %%%%%%%%%%%%%
    set(f,  'NumberTitle', 'off',...
                   'Name', 'Two-bar statics');
    set(f, 'Visible', 'on')
    %%%%%%%%%% First nested functions %%%%%%%%%%%%%%%%
    % Set the value of the first edit text box String property
    % to the value of the slider and the value of the second
    % edit text box to 1500 - the value of the slider
    function slider_callback(hObject, eventdata)
            val = get(hObject, 'Value');
            set(hedit1, 'String', num2str(fix(val)));
            set(hedit2, 'String', num2str(1500 - fix(val)));
            [ r1 r2 R1 R2 ]  = PlotCalc(val);         
    end
    % Set the slider value to the number the user types in 
    % the first edit text or display an error message.
    function edittext_callback(hObject,eventdata)
        val = str2double(get(hslide, 'Value'));
        previous_val = val;
        val = str2double(get(hObject,'String'));
        % Determine whether val is a number between the 
        % slider's Min and Max. If it is, set the slider Value.
        if isnumeric(val) && length(val) == 1 && ...
                val >= get(hslide, 'Min') && ...
                val <= get(hslide, 'Max')
                set(hslide, 'Value', val);
                set(hedit2, 'String', num2str(1500 - val));
                [ r1 r2 R1 R2 ]  = PlotCalc(val); 
              
        else
                set(hObject,'String', 'Invalid entry ');
                 val = previous_val;
        end
    end  
  % Set the value of the second edit text box String property
   % to 1500 - the value of the slider and the value of the first
    % edit text box to the value of the slider
    function slider_callback2(hObject, eventdata)
            val = get(hObject, 'Value');
            set(hedit2, 'String', num2str(fix(val)));
            val1 = 1500 -val;
            set(hedit1, 'String', num2str(fix(val1)));
            [ r1 r2 R1 R2 ]  = PlotCalc(val1);         
    end
    % Set the slider value to the number the user types in 
    % the second edit text or display an error message.
    function edittext_callback2(hObject,eventdata)
        val = str2double(get(hslide, 'Value'));
        previous_val = val;
        val = str2double(get(hObject,'String'));
        % Determine whether val is a number between the 
        % slider's Min and Max. If it is, set the slider Value.
        if isnumeric(val) && length(val) == 1 && ...
                val >= get(hslide, 'Min') && ...
                val <= get(hslide, 'Max')
                val1 = 1500 -val;
                set(hslide, 'Value', val1);
                set(hedit1, 'String', num2str(val1));
                [ r1 r2 R1 R2 ]  = PlotCalc(val1); 
        else
                set(hObject,'String', 'Invalid entry ');
                 val = previous_val;
        end
    end        
        function [ r1 r2 R1 R2 ] = PlotCalc(val)   
                 [ r1 r2 R1 R2 ]    = Stat1FigFun(val);
                 nd                         = 3;  % number of displayed decimal digits
                 p                            = 10^nd;     
                 r1                          = fix(p*r1)/p;
                 r2                          = fix(p*r2)/p;
                 R1                          = fix(p*R1)/p;
                 R2                          = fix(p*R2)/p;
                 set(hedit3, 'String',  R1(1));
                 set(hedit4, 'String',  R1(2));
                 set(hedit5, 'String',  r1);
                 set(hedit6, 'String',  R2(1));
                 set(hedit7, 'String',  R2(2));
                 set(hedit8, 'String',  r2);
        end
end    