function [ x, y ] = gunvac(v0, alpha);

%GUNVAC  Plots the trajectory  of a  shell in vacuum
%Input arguments:  x0 - initial shell velocity, m/s
%                                          alpha, angle between gun axis and horizontal, deg
% Output arguments: x, y - cartesian coordinates
% Can be used as an example in Chapter 2 of the book
% What very engineer should know about MATLAB and Simulink'.
% Written be Adrian Biran.

g    = 9.81;                                                          % acceleration of gravity, m/s^2
v    = v0*[ cosd(alpha) sind(alpha) ];  % velocity vector, m/s
tf = 2*v(2)/g;                                                   % terminal time, s
t    = linspace(0, tf);                                % time scale , s
x    = v(1)*t;                                                      % horizontal travel, m
y    = v(2)*t - g*t.^2/2;                                    % vertical travel, m
plot(x, y), grid
axis equal
t = [ 'Trajectory in vacuum for v_0 = ' num2str(v0) ' and \alpha = '  ];
t = [ t num2str(alpha) ' degrees' ];
title(t)
xlabel(' x, m')
ylabel('y, m')
    