function  x = newton(h, hdot, x0, tol)

%NEWTON  Newton-Raphson procedure
%                  Input arguments:
%                         h, given equation defined as anonymous function
%                         hdot, derivative of h, defined as anonymous function
%                         x0, initial guess
%                         tol, difference between two successive solutions,
%                         optional
%                   Output argument: x, solution within aproximation tol
% Written by Adrian Biran for Subsection 3.9.1 in `What every engineer
% should know about MATLAB and Simulink'.
   
if nargin == 3
        tol = 10^(-6);
end        
xi    = x0;
eps  = 1;
while  eps > tol
        y         = feval(h, xi);
        ydot = feval(hdot, xi);
        xi1    = xi - y/ydot;
        eps   = abs(xi1 - xi);
        xi      = xi1;
end 
x = xi;