function    p = perim(Polyline)

%PERIM      Calculates the length of the polygonal line Polyline.
%                    For n points (vertices) Polyline is a 2-by-n array. The 
%                    first line represents the x-coordinates of
%                    the n points, the second line, their y-coordinates. 
%                    If Polyline is a closed polygon, the last point is
%                    the repetition of the first point. 
%                    Developed by Adrian Biran for Subsection 2.1.3, `Vectorization'
%                    in `What every engineer should know about MATLAB and
%                    Simulink'.

dpx = diff(Polyline(1, :));
dpy = diff(Polyline(2, :));
ds    = (dpx.^2 + dpy.^2).^(0.5);  % lengths of sides                           
p       = sum(ds);