function    [ R1 R2 ] = statics1(w, a, b, c)

%STATICS1   Finds tensions in two bars connected to a point
%                       where a weight w hangs 
%                       a -  horizontal distance between first articulation
%                       and the vertical of w
%                       b - horizontal distance between the second
%                       articulation and the vertical of w
%                       c - vertical ditance between the plane of
%                       articulations and the point where w hangs
%                       See Example 2.4 in `What every engineer should know
%                       about MATLAB and Simulink'.
%                       Written by Adrian Biran, May 2009
% calculate angles
alpha = atand(a/c);
beta    = atand(b/c);
gamma = 180 - alpha - beta;
% calculate magnitudes of tension vectors
r1          = sind(beta)*w/sind(gamma);
r2          = sind(alpha)*w/sind(gamma);
% define tension vectors
R1          = r1*[ -sind(alpha), cosd(alpha) ];
R2          = r2*[  sind(beta), cosd(beta) ];
