function varrow(o, e, t)
%VARROW draws vertical arrow of thickness t, from origin o to end e 
%               in a three-dimensional plot. The input arguments
%               0 and e should be supplied as three-dimensional vectors.
%               The arrow corresponds to the ISO recommendations
%               drawing standards.
%               Written by Adrian Biran., September 2009,
%               for the book `What every engineer should know
%               about MATLAB and Simulink'


% draw support
plot3([ o(1) e(1) ], [ o(2) e(2) ], [ o(3) e(3) ],  'k-', 'LineWidth', t)
% hold on
H           = 5*t;
zB        = e(3)  - H;
R           = H*tand(7.5);
n           = 20;                                                % plot resolution
u           = (0:n)/n;                                        % u parameter  
v           = (n: -1: 0)/n;                                 % v parameter
theta = 2*pi*u;                                      % angle corresponding to u parameter
xs         = R*cos(theta);                        % x coordinate on base circle
ys         = R*sin(theta);                        % y coordinate on base circle  
xxs       = v'*xs;                                        % (n+1)-by(n+1) array of x-coordinates on cone surface
yys       = e(2) + v'*ys;                             % (n+1)-by(n+1) array of y-coordinates on cone surface  
zs          =  zB + (1 - v)*H;                          % (n+1)-by(n+1) array of z-coordinates on cone surface
zzs       = zs'*ones(size(v));

hs = surf(xxs, yys, zzs);                    % plot cone surface
axis equal, axis off
colormap(gray)

